from . import errors
import requests
import json


class build():
    def __init__(self, APIKey=None):
        if not APIKey:
            raise errors.MissingAPIKey()
        self.key = APIKey

    def search(self, sKeyword, sMax=5, sType=["video", "channel", "playlist"]):
        value = requests.get(
            f"https://www.googleapis.com/youtube/v3/search?type={','.join(sType)}\
                &maxResults={sMax}&part=snippet&q={sKeyword}&key={self.key}"
                ).json()
        try:
            value["items"]
        except KeyError:
            if value["error"]["errors"][0]["reason"] == "keyInvalid":
                raise errors.WrongAPIKey()
            else:
                raise errors.SearchError(
                    f"{value['error']['errors'][0]['reason']}\n\
                        https://developers.google.com/youtube/v3/docs/errors")
        self.value = value
        r = searched(self.forlist("title"), self.forlist("channelId"),
                     self.forlist("channelTitle"), self.forlist("description"),
                     [i["id"]["kind"] for i in self.value["items"]],
                     [i["id"].get("videoId") for i in self.value["items"]],
                     [i["id"].get("playlistId") for i in self.value["items"]])

        return r

    def forlist(self, flist):
        return [i["snippet"][flist] for i in self.value["items"]]


class searched(object):
    def __init__(self, title, channelId, channelTitle,
                 description, sType, videoId, playlistId):
        self.title = title
        self.channelId = channelId
        self.channelTitle = channelTitle
        self.description = description
        self.sType = sType
        self.videoId = videoId
        self.playlistId = playlistId



from setuptools import setup
from codecs import open
from os import path

setup(
    name='yt_search',
    packages=['yt_search'],
    version='1.1.0',
    python_requires='>=3.6',
    license='GPLv3',
    author='jun50',
    author_email='0001jun50@gmail.com',
    description='Search contents on YouTube.',
    long_description=open('README.md', encoding="utf-8").read(),
    long_description_content_type='text/markdown',
    keywords='YouTube API',
    classifiers=[
        'License :: OSI Approved :: GNU General Public License v3 (GPLv3)',
        'Programming Language :: Python :: 3.7',
	'Programming Language :: Python :: 3.6',
    ]
)
